/**
 * 検索タブJS
 *
 * 例
 * <link rel="stylesheet" type="text/css" href="SearchTab.css" />
 * <div class="search_div">
 * <div class="tab">
 * <ul>
 * <li class="first"><span><a href="http://example.com/" id="t1" onclick="javascript:ST.click('t1');" hidefocus="true">ウェブ</a></span></li>
 * <li><span><a href="http://example2.com/" id="t2" onclick="javascript:ST.click('t2');" hidefocus="true">動画</a></span></li>
 * <li class="last"><span><a href="http://example3.com/" id="t3" onclick="javascript:ST.click('t3');" hidefocus="true">写真</a></span></li>
 * </ul>
 * <div class="clear"></div>
 * </div>
 * <form name="search_form" id="search_form" action="http://example1.com/" onKeydown="return ST.submitCheck();" target="_blank">
 * <input type="text" name="q" size="60" maxlength="255">
 * <input type="submit" name="b1" value="ウェブ検索" class="submit" onClick="ST.submit();return false;">
 * </form>
 * </div>
 * <script type="text/javascript" src="SearchTab.js"></script>
 * <script type="text/javascript">
 * var ST = new SearchTabClass({
 * "ids": new Array("t1", "t2", "t3"),
 * "urls": new Array("http://example.com/?", "http://example2.com/?", "http://example3.com/?"),
 * "inputTextPath": "document.search_form.q",
 * "buttons": new Array("ウェブ検索", "動画検索", "写真検索"),
 * "buttonPath": "document.search_form.b1",
 * "linkColor": "blue"
 * });
 * ST.load();
 * </script>
 */

// 
/**
 * 検索タブクラスのコンストラクタ
 *
 * @param    object    obj
 *                     + id            初期選択id            必須
 *                     + ids           選択可能id            必須
 *                     + urls          選択可能ボタン名      必須
 *                     + inputTextPath テキストフォームパス  必須
 *                     + buttons       選択可能ボタン名
 *                     + buttonPath    ボタンフォームパス
 *                     + linkColor     リンクカラー
 * @return   void
 */
var SearchTabClass = function(obj) {
    /**#@+
     * @access private
     */
    this._id;
    this._ids = obj["ids"];
    this._urls = obj["urls"];
    this._inputText = eval(obj["inputTextPath"]);
    this._inputTextPath = obj["inputTextPath"];
    if (obj["buttons"] != undefined) {
        this._buttons = obj["buttons"];
    }
    if (obj["buttonPath"] != undefined) {
        this._button = eval(obj["buttonPath"]);
    }
    if (obj["linkColor"] != undefined) {
        this._linkColor = obj["linkColor"];
    } else {
        this._linkColor = "blue";
    }
    /**#@-*/
    
    this.errorCheck();
}
// 検索タブクラスのメソッド一覧
SearchTabClass.prototype = {
    
    /**#@+
     * @access public
     */
    
    //--------------------------------------------------
    /**
     * ロード
     *
     * @param    string    id    初期選択id
     * @return   void
     */
    load: function(id) {
        for (i in this._ids) {
            this._getObj(this._ids[i]).href = "javascript:void(0);";
        }
        this.click(id);
    },
    //--------------------------------------------------
    /**
     * 上部タブクリックイベント
     *
     * @param    string    id    初期選択id
     * @return   void
     */
    click: function(id) {
        this._clickReset();
        if (id == undefined) id = this._ids[0];
        for (var i in this._ids) {
            if (this._ids[i] == id) {
                if (this._button) {
                    this._button.value = this._buttons[i];
                }
                break;
            }
        }
        this._getObjStyle(id).color = "black";
        this._getObjStyle(id).fontWeight = "bold";
        this._id = id;
        this._inputText.focus();
    },
    //--------------------------------------------------
    /**
     * 検索ボタンクリックイベント
     *
     * @return   void
     */
    submit: function() {
        var q = this._inputText.value;
        var eq = encodeURI(q);
        var id = this._id;
        var url;
        if (id == undefined) id = this._ids[0];
        for (i in this._ids) {
            if (this._ids[i] == id) {
                url = this._urls[i] + eq;
                break;
            }
        }
        window.open(url, "_blank");
    },
    //--------------------------------------------------
    /**
     * 検索ボタン実行チェック
     *
     * @return   boolean
     */
    submitCheck: function() {
        if (event.keyCode == 13) {    // enterKey
            this.submit();
            return false;
        }
        return true;
    },
    //--------------------------------------------------
    /**
     * エラーチェック
     *
     * @return   void
     */
    errorCheck: function() {
        if (!this._inputText) {
            alert(this._inputTextPath + "が存在しません。");
        }
    },
    /**#@-*/
    
    /**#@+
     * @access private
     */
    
    //--------------------------------------------------
    /**
     * 上部タブクリックリセット
     *
     * @return   void
     */
    _clickReset: function() {
        for (i in this._ids) {
            this._getObjStyle(this._ids[i]).color = this._linkColor;
            this._getObjStyle(this._ids[i]).fontWeight = "normal";
        }
    },
    //--------------------------------------------------
    /**
     * オブジェクトスタイル取得
     *
     * @param    string    Lyid
     * @return   object    myObj
     */
    _getObjStyle: function(Lyid) {
        var myObj;
        // ブラウザ判定
        if (document.getElementById) {
            myObj = document.getElementById(Lyid).style;    // N6
        } else if (document.all) {
            myObj = document.all[Lyid].style;                // IE
        } else if (document.layers) {
            myObj = document[Lyid];                            // N4
        }
        return myObj;
    },
    //--------------------------------------------------
    /**
     * オブジェクト取得
     *
     * @param    string    Lyid
     * @return   object    myObj
     */
    _getObj: function(Lyid) {
        var myObj;
        // ブラウザ判定
        if (document.getElementById) {
            myObj = document.getElementById(Lyid);    // N6
        } else if (document.all) {
            myObj = document.all[Lyid];                // IE
        } else if (document.layers) {
            myObj = document[Lyid];                    // N4
        }
        return myObj;
    }
    /**#@-*/
};